@@ -53,36 +53,50 @@ class UBXReader:
     UBXReader class.
     """
 
-    def __init__(self, datastream, **kwargs):
+    def __init__(
+        self,
+        datastream,
+        msgmode: int = GET,
+        validate: int = VALCKSUM,
+        protfilter: int = NMEA_PROTOCOL | UBX_PROTOCOL,
+        quitonerror: int = ERR_LOG,
+        parsebitfield: bool = True,
+        scaling: bool = True,
+        labelmsm: bool = True,
+        bufsize: int = 4096,
+        parsing: bool = True,
+        errorhandler: object = None,
+    ):
         """Constructor.
 
         :param datastream stream: input data stream
-        :param int quitonerror: (kwarg) 0 = ignore errors,  1 = log continue, 2 = (re)raise (1)
-        :param int errorhandler: (kwarg) error handling object or function (None)
-        :param int protfilter: (kwarg) protocol filter 1 = NMEA, 2 = UBX, 4 = RTCM3 (3)
-        :param int validate: (kwarg) 0 = ignore invalid checksum, 1 = validate checksum (1)
-        :param int msgmode: (kwarg) 0=GET, 1=SET, 2=POLL (0)
-        :param bool parsebitfield: (kwarg) 1 = parse bitfields, 0 = leave as bytes (1)
-        :param bool scaling: (kwarg) 1 = apply scale factors, 0 = do not apply (1)
-        :param bool labelmsm: (kwarg) whether to label RTCM3 MSM NSAT and NCELL attributes (1)
-        :param int bufsize: (kwarg) socket recv buffer size (1024)
+        :param int msgmode: 0=GET, 1=SET, 2=POLL (0)
+        :param int validate: 0 = ignore invalid checksum, 1 = validate checksum (1)
+        :param int protfilter: protocol filter 1 = NMEA, 2 = UBX, 4 = RTCM3 (3)
+        :param int quitonerror: 0 = ignore errors,  1 = log continue, 2 = (re)raise (1)
+        :param bool parsebitfield: 1 = parse bitfields, 0 = leave as bytes (1)
+        :param bool scaling: 1 = apply scale factors, 0 = do not apply (1)
+        :param bool labelmsm: whether to label RTCM3 MSM NSAT and NCELL attributes (1)
+        :param int bufsize: socket recv buffer size (1024)
+        :param bool parsing: True = parse data, False = don't parse data (output raw only) (True)
+        :param int errorhandler: error handling object or function (None)
         :raises: UBXStreamError (if mode is invalid)
-
         """
+        # pylint: disable=too-many-arguments
 
-        bufsize = int(kwargs.get("bufsize", 4096))
         if isinstance(datastream, socket):
             self._stream = SocketStream(datastream, bufsize=bufsize)
         else:
             self._stream = datastream
-        self._protfilter = int(kwargs.get("protfilter", NMEA_PROTOCOL | UBX_PROTOCOL))
-        self._quitonerror = int(kwargs.get("quitonerror", ERR_LOG))
-        self._errorhandler = kwargs.get("errorhandler", None)
-        self._validate = int(kwargs.get("validate", VALCKSUM))
-        self._parsebf = int(kwargs.get("parsebitfield", True))
-        self._scaling = int(kwargs.get("scaling", True))
-        self._labelmsm = int(kwargs.get("labelmsm", True))
-        self._msgmode = int(kwargs.get("msgmode", GET))
+        self._protfilter = protfilter
+        self._quitonerror = quitonerror
+        self._errorhandler = errorhandler
+        self._validate = validate
+        self._parsebf = parsebitfield
+        self._scaling = scaling
+        self._labelmsm = labelmsm
+        self._msgmode = msgmode
+        self._parsing = parsing
 
         if self._msgmode not in (0, 1, 2):
             raise UBXStreamError(
@@ -122,10 +136,10 @@ class UBXReader:
         :raises: UBXStreamError (if unrecognised protocol in data stream)
         """
 
-        parsing = True
+        flag = True
 
         try:
-            while parsing:  # loop until end of valid message or EOF
+            while flag:  # loop until end of valid message or EOF
                 raw_data = None
                 parsed_data = None
                 byte1 = self._read_bytes(1)  # read the first byte
@@ -140,7 +154,7 @@ class UBXReader:
                     # if protocol filter passes UBX, return message,
                     # otherwise discard and continue
                     if self._protfilter & UBX_PROTOCOL:
-                        parsing = False
+                        flag = False
                     else:
                         continue
                 # if it's an NMEA message ('$G' or '$P')
@@ -149,7 +163,7 @@ class UBXReader:
                     # if protocol filter passes NMEA, return message,
                     # otherwise discard and continue
                     if self._protfilter & NMEA_PROTOCOL:
-                        parsing = False
+                        flag = False
                     else:
                         continue
                 # if it's a RTCM3 message
@@ -159,7 +173,7 @@ class UBXReader:
                     # if protocol filter passes RTCM, return message,
                     # otherwise discard and continue
                     if self._protfilter & RTCM3_PROTOCOL:
-                        parsing = False
+                        flag = False
                     else:
                         continue
                 # unrecognised protocol header
@@ -212,7 +226,7 @@ class UBXReader:
         cksum = byten[leni : leni + 2]
         raw_data = hdr + clsid + msgid + lenb + plb + cksum
         # only parse if we need to (filter passes UBX)
-        if self._protfilter & UBX_PROTOCOL:
+        if (self._protfilter & UBX_PROTOCOL) and self._parsing:
             parsed_data = self.parse(
                 raw_data,
                 validate=self._validate,
@@ -240,12 +254,11 @@ class UBXReader:
             raise EOFError()
         raw_data = hdr + byten
         # only parse if we need to (filter passes NMEA)
-        if self._protfilter & NMEA_PROTOCOL:
+        if (self._protfilter & NMEA_PROTOCOL) and self._parsing:
             # invoke pynmeagps parser
             parsed_data = NMEAReader.parse(
                 raw_data,
                 validate=self._validate,
-                quitonerror=self._quitonerror,
                 msgmode=self._msgmode,
             )
         else:
@@ -268,12 +281,11 @@ class UBXReader:
         crc = self._read_bytes(3)
         raw_data = hdr + hdr3 + payload + crc
         # only parse if we need to (filter passes RTCM)
-        if self._protfilter & RTCM3_PROTOCOL:
+        if (self._protfilter & RTCM3_PROTOCOL) and self._parsing:
             # invoke pyrtcm parser
             parsed_data = RTCMReader.parse(
                 raw_data,
                 validate=self._validate,
-                quitonerror=self._quitonerror,
                 scaling=self._scaling,
                 labelmsm=self._labelmsm,
             )
@@ -325,7 +337,14 @@ class UBXReader:
         return self._stream
 
     @staticmethod
-    def parse(message: bytes, **kwargs) -> object:
+    def parse(
+        message: bytes,
+        msgmode: int = GET,
+        validate: int = VALCKSUM,
+        quitonerror: int = ERR_LOG,
+        parsebitfield: bool = True,
+        scaling: bool = True,
+    ) -> object:
         """
         Parse UBX byte stream to UBXMessage object.
 
@@ -333,22 +352,16 @@ class UBXReader:
         (the UBXMessage constructor can calculate and assign its own values anyway).
 
         :param bytes message: binary message to parse
-        :param int quitonerror: (kwarg) 0 = ignore errors,  1 = log continue, 2 = (re)raise (1)
-        :param int validate: (kwarg) validate cksum (VALCKSUM (1)=True (default), VALNONE (0)=False)
-        :param int msgmode: (kwarg) message mode (0=GET (default), 1=SET, 2=POLL)
-        :param bool parsebitfield: (kwarg) 1 = parse bitfields, 0 = leave as bytes (1)
-        :param bool scaling: (kwarg) 1 = apply scale factors, 0 = do not apply (1)
+        :param int quitonerror: 0 = ignore errors,  1 = log continue, 2 = (re)raise (1)
+        :param int validate: validate cksum (VALCKSUM (1)=True (default), VALNONE (0)=False)
+        :param int msgmode: message mode (0=GET (default), 1=SET, 2=POLL)
+        :param bool parsebitfield: 1 = parse bitfields, 0 = leave as bytes (1)
+        :param bool scaling: 1 = apply scale factors, 0 = do not apply (1)
         :return: UBXMessage object
         :rtype: UBXMessage
         :raises: UBXParseError (if data stream contains invalid data or unknown message type)
-
         """
-
-        quitonerror = int(kwargs.get("quitonerror", ERR_LOG))
-        msgmode = kwargs.get("msgmode", GET)
-        validate = kwargs.get("validate", VALCKSUM)
-        parsebf = kwargs.get("parsebitfield", True)
-        scaling = kwargs.get("scaling", True)
+        # pylint: disable=too-many-arguments
 
         if msgmode not in (0, 1, 2):
             raise UBXParseError(f"Invalid message mode {msgmode} - must be 0, 1 or 2")
@@ -393,7 +406,7 @@ class UBXReader:
                 msgid,
                 msgmode,
                 payload=payload,
-                parsebitfield=parsebf,
+                parsebitfield=parsebitfield,
                 scaling=scaling,
             )
         except KeyError as err:
