@@ -3,7 +3,7 @@ UBX Protocol core globals and constants
 
 Created on 27 Sep 2020
 
-Information sourced from u-blox Interface Specifications © 2013-2021, u-blox AG
+Information sourced from public domain u-blox Interface Specifications © 2013-2021, u-blox AG
 
 :author: semuadmin
 """
@@ -30,6 +30,7 @@ GNSSLIST = {
     4: "IMES",
     5: "QZSS",
     6: "GLONASS",
+    7: "NAVIC",
 }
 
 # scaling factor constants
