@@ -6,7 +6,7 @@ THESE ARE THE PAYLOAD DEFINITIONS FOR _GET_ MESSAGES _FROM_ THE RECEIVER
 
 Created on 27 Sep 2020
 
-Information sourced from u-blox Interface Specifications © 2013-2021, u-blox AG
+Information sourced from public domain u-blox Interface Specifications © 2013-2021, u-blox AG
 
 :author: semuadmin
 """
@@ -3294,12 +3294,12 @@ UBX_PAYLOADS_GET = {
     "RXM-SFRBX": {
         "gnssId": U1,
         "svId": U1,
-        "reserved0": U1,
+        "sigId": U1,
         "freqId": U1,
         "numWords": U1,
         "chn": U1,
         "version": U1,
-        "reserved1": U1,
+        "reserved0": U1,
         "navdata": ("numWords", {"dwrd": U4}),  # repeating group * numWords
     },
     "RXM-SPARTN": {
